aboutsummaryrefslogtreecommitdiff
path: root/gcc
diff options
context:
space:
mode:
authorOndřej Bílka <neleai@seznam.cz>2013-07-21 18:40:33 +0000
committerMike Stump <mrs@gcc.gnu.org>2013-07-21 18:40:33 +0000
commitd4aef883b7470379c369588dbea57315e1c67a4c (patch)
treea4c17100219c6730eb84bf3d9da2bdf66c0bc5cb /gcc
parent688010bad0375a275466ac1adb98aff80c0e77ac (diff)
downloadgcc-d4aef883b7470379c369588dbea57315e1c67a4c.zip
gcc-d4aef883b7470379c369588dbea57315e1c67a4c.tar.gz
gcc-d4aef883b7470379c369588dbea57315e1c67a4c.tar.bz2
gigi.h: Likewise.
2013-07-21 Ondřej Bílka <neleai@seznam.cz> * gcc-interface/gigi.h: Likewise. * gcc-interface/trans.c: Likewise. * gcc-interface/utils2.c: Likewise. * gnat_rm.texi: Likewise. * gnat_ugn.texi: Likewise. * raise-gcc.c: Likewise. * sigtramp-ppcvxw.c: Likewise. * sysdep.c: Likewise. * terminals.c: Likewise. From-SVN: r201111
Diffstat (limited to 'gcc')
-rw-r--r--gcc/ada/ChangeLog12
-rw-r--r--gcc/ada/gcc-interface/gigi.h2
-rw-r--r--gcc/ada/gcc-interface/trans.c4
-rw-r--r--gcc/ada/gcc-interface/utils2.c6
-rw-r--r--gcc/ada/gnat_rm.texi4
-rw-r--r--gcc/ada/gnat_ugn.texi4
-rw-r--r--gcc/ada/raise-gcc.c2
-rw-r--r--gcc/ada/sigtramp-ppcvxw.c2
-rw-r--r--gcc/ada/sysdep.c2
-rw-r--r--gcc/ada/terminals.c6
10 files changed, 28 insertions, 16 deletions
diff --git a/gcc/ada/ChangeLog b/gcc/ada/ChangeLog
index ef11805..4e0b0a8 100644
--- a/gcc/ada/ChangeLog
+++ b/gcc/ada/ChangeLog
@@ -1,3 +1,15 @@
+2013-07-21 Ondřej Bílka <neleai@seznam.cz>
+
+ * gcc-interface/gigi.h: Likewise.
+ * gcc-interface/trans.c: Likewise.
+ * gcc-interface/utils2.c: Likewise.
+ * gnat_rm.texi: Likewise.
+ * gnat_ugn.texi: Likewise.
+ * raise-gcc.c: Likewise.
+ * sigtramp-ppcvxw.c: Likewise.
+ * sysdep.c: Likewise.
+ * terminals.c: Likewise.
+
2013-07-20 Eric Botcazou <ebotcazou@adacore.com>
PR ada/57934
diff --git a/gcc/ada/gcc-interface/gigi.h b/gcc/ada/gcc-interface/gigi.h
index 8ee6660..d18fd4d 100644
--- a/gcc/ada/gcc-interface/gigi.h
+++ b/gcc/ada/gcc-interface/gigi.h
@@ -1043,7 +1043,7 @@ extern void enumerate_modes (void (*f) (const char *, int, int, int, int, int,
}
#endif
-/* Let code know whether we are targetting VMS without need of
+/* Let code know whether we are targeting VMS without need of
intrusive preprocessor directives. */
#ifndef TARGET_ABI_OPEN_VMS
#define TARGET_ABI_OPEN_VMS 0
diff --git a/gcc/ada/gcc-interface/trans.c b/gcc/ada/gcc-interface/trans.c
index 4b224ab..f91f4b8 100644
--- a/gcc/ada/gcc-interface/trans.c
+++ b/gcc/ada/gcc-interface/trans.c
@@ -64,7 +64,7 @@
instead. */
#define ALLOCA_THRESHOLD 1000
-/* Let code below know whether we are targetting VMS without need of
+/* Let code below know whether we are targeting VMS without need of
intrusive preprocessor directives. */
#ifndef TARGET_ABI_OPEN_VMS
#define TARGET_ABI_OPEN_VMS 0
@@ -9163,7 +9163,7 @@ set_end_locus_from_node (tree gnu_node, Node_Id gnat_node)
/* Pick the GNAT node of which we'll take the sloc to assign to the GCC node
end_locus when there is one. We consider only GNAT nodes with a possible
End_Label attached. If the End_Label actually was unassigned, fallback
- on the orginal node. We'd better assign an explicit sloc associated with
+ on the original node. We'd better assign an explicit sloc associated with
the outer construct in any case. */
switch (Nkind (gnat_node))
diff --git a/gcc/ada/gnat_rm.texi b/gcc/ada/gnat_rm.texi
index 03bf611..c1109b9 100644
--- a/gcc/ada/gnat_rm.texi
+++ b/gcc/ada/gnat_rm.texi
@@ -2488,7 +2488,7 @@ location of the declaration of the entity to eliminate in a generic unit.
Note that the @code{Source_Location} argument specifies which of a set of
similarly named entities is being eliminated, dealing both with overloading,
-and also appearence of the same entity name in different scopes.
+and also appearance of the same entity name in different scopes.
This pragma indicates that the given entity is not used in the program to be
compiled and built. The effect of the pragma is to allow the compiler to
@@ -7072,7 +7072,7 @@ these three specific cases are treated as literal characters in the match.
The above use of patterns to match the message applies only to warning
messages generated by the front end. This form of the pragma with a
string argument can also be used to control back end warnings controlled
-by a "-Wxxx" switch. Such warnings can be identified by the appearence
+by a "-Wxxx" switch. Such warnings can be identified by the appearance
of a string of the form "[-Wxxx]" in the message which identifies the
"-W" switch that controls the message. By using the text of the
"-W" switch in the pragma, such back end warnings can be turned on and off.
diff --git a/gcc/ada/gnat_ugn.texi b/gcc/ada/gnat_ugn.texi
index 4099ace5..0a5f07d 100644
--- a/gcc/ada/gnat_ugn.texi
+++ b/gcc/ada/gnat_ugn.texi
@@ -2316,7 +2316,7 @@ are unlikely to be able to be passed.
Note that in the case of GNAT running
on a platform that supports HP Ada 83, a higher degree of compatibility
-can be guaranteed, and in particular records are layed out in an identical
+can be guaranteed, and in particular records are laid out in an identical
manner in the two compilers. Note also that if output from two different
compilers is mixed, the program is responsible for dealing with elaboration
issues. Probably the safest approach is to write the main program in the
@@ -26171,7 +26171,7 @@ would prefer this precondition to be considered True at run time).
@noindent
To deal with the portability issue, and with the problem of
-mathematical versus run-time intepretation of the expressions in
+mathematical versus run-time interpretation of the expressions in
assertions, GNAT provides comprehensive control over the handling
of intermediate overflow. GNAT can operate in three modes, and
furthemore, permits separate selection of operating modes for
diff --git a/gcc/ada/raise-gcc.c b/gcc/ada/raise-gcc.c
index a428642..d804564 100644
--- a/gcc/ada/raise-gcc.c
+++ b/gcc/ada/raise-gcc.c
@@ -231,7 +231,7 @@ db_phases (int phases)
If it is determined that indeed an action should be taken, that
is, if one action filter matches the exception being propagated,
- then control should be transfered to landing-pad.
+ then control should be transferred to landing-pad.
A null first-action-index indicates that there are only cleanups
to run there.
diff --git a/gcc/ada/sigtramp-ppcvxw.c b/gcc/ada/sigtramp-ppcvxw.c
index bb6945b..69baa14 100644
--- a/gcc/ada/sigtramp-ppcvxw.c
+++ b/gcc/ada/sigtramp-ppcvxw.c
@@ -131,7 +131,7 @@ void __gnat_sigtramp (int signo, void *si, void *sc,
#define REGNO_PC 67 /* ARG_POINTER_REGNUM */
-/* asm string contruction helpers. */
+/* asm string construction helpers. */
#define STR(TEXT) #TEXT
/* stringify expanded TEXT, surrounding it with double quotes. */
diff --git a/gcc/ada/sysdep.c b/gcc/ada/sysdep.c
index 1eec8b9..58c51c0 100644
--- a/gcc/ada/sysdep.c
+++ b/gcc/ada/sysdep.c
@@ -721,7 +721,7 @@ __gnat_localtime_tzoff (const time_t *timer, const int *is_historic, long *off)
&& SystemTimeToTzSpecificLocalTime (&tzi, &utc_sys_time, &local_sys_time)
&& SystemTimeToFileTime (&local_sys_time, &local_time.ft_time);
- /* An error has occured, return invalid_tzoff */
+ /* An error has occurred, return invalid_tzoff */
if (!status) {
*off = __gnat_invalid_tzoff;
diff --git a/gcc/ada/terminals.c b/gcc/ada/terminals.c
index 36b97a6..dfadca8 100644
--- a/gcc/ada/terminals.c
+++ b/gcc/ada/terminals.c
@@ -295,7 +295,7 @@ nt_spawnve (char *exe, char **argv, char *env, struct TTY_Process *process)
Note that using backslash to escape embedded quotes requires
additional special handling if an embedded quote is already
- preceeded by backslash, or if an arg requiring quoting ends with
+ preceded by backslash, or if an arg requiring quoting ends with
backslash. In such cases, the run of escape characters needs to be
doubled. For consistency, we apply this special handling as long
as the escape character is not quote.
@@ -1332,7 +1332,7 @@ __gnat_setup_child_communication
#endif
#ifdef TIOCSCTTY
- /* make the tty the controling terminal */
+ /* make the tty the controlling terminal */
status = ioctl (desc->slave_fd, TIOCSCTTY, 0);
#endif
@@ -1420,7 +1420,7 @@ int __gnat_terminate_process (pty_desc *desc)
return kill (desc->child_pid, SIGKILL);
}
-/* __gnat_tty_waitpid - wait for the child proces to die
+/* __gnat_tty_waitpid - wait for the child process to die
*
* PARAMETERS
* desc pty_desc structure
diff --git a/gcc/ada/gcc-interface/utils2.c b/gcc/ada/gcc-interface/utils2.c
index 3f39a43..7f7f6af 100644
--- a/gcc/ada/gcc-interface/utils2.c
+++ b/gcc/ada/gcc-interface/utils2.c
@@ -1902,7 +1902,7 @@ build_simple_component_ref (tree record_variable, tree component,
{
tree new_field;
/* First loop thru normal components. */
for (new_field = TYPE_FIELDS (record_type);
new_field;
new_field = DECL_CHAIN (new_field))
@@ -1910,7 +1910,7 @@ build_simple_component_ref (tree record_variable, tree component,
break;
/* Next, see if we're looking for an inherited component in an extension.
- If so, look thru the extension directly, but not if the type contains
+ If so, look through the extension directly, but not if the type contains
a placeholder, as it might be needed for a later substitution. */
if (!new_field
&& TREE_CODE (record_variable) == VIEW_CONVERT_EXPR
@@ -1926,7 +1926,7 @@ build_simple_component_ref (tree record_variable, tree component,
return ref;
}
/* Next, loop thru DECL_INTERNAL_P components if we haven't found the
component in the first search. Doing this search in two steps is
required to avoid hidden homonymous fields in the _Parent field. */
if (!new_field)
@@ -1902,7 +1902,7 @@ build_simple_component_ref (tree record_variable, tree component,
{
tree new_field;
- /* First loop thru normal components. */
+ /* First loop through normal components. */
for (new_field = TYPE_FIELDS (record_type);
new_field;
@@ -1926,7 +1926,7 @@ build_simple_component_ref (tree record_variable, tree component,
return ref;
}
- /* Next, loop thru DECL_INTERNAL_P components if we haven't found the
+ /* Next, loop through DECL_INTERNAL_P components if we haven't found the
component in the first search. Doing this search in two steps is
required to avoid hidden homonymous fields in the _Parent field. */